pub struct LiveTableData { /* private fields */ }Expand description
Wraps a table’s data so we can dynamically push new batches. The MemTable is created on initialization and shared with queries.
Implementations
Sourceimpl LiveTableData
impl LiveTableData